@@ -10,7 +10,7 @@ use opencv::{
 #[test]
 fn knn() -> Result<()> {
 	let mut knn = <dyn KNearest>::create()?;
-	assert!(StatModel::empty(&knn)?);
+	assert!(StatModelConst::empty(&knn)?);
 	let samp = Mat::new_rows_cols_with_default(1, 1, f32::typ(), Scalar::all(1.))?;
 	let resp = Mat::new_rows_cols_with_default(1, 1, f32::typ(), Scalar::all(2.))?;
 	knn.train(&samp, ml::ROW_SAMPLE, &resp)?;
